@@ -1,5 +1,5 @@
-__version__ = '1.6'
+__version__ = '1.18'
 
-from .types import Message, CallbackQuery, Chat, User
+from .types import Message, CallbackQuery, Chat, User, DeletedMessages
 from .media_attributes import AnimationAttributes, AudioAttributes, DocumentAttributes, \
     PhotoAttributes, VideoAttributes, VideoNoteAttributes, VoiceAttributes, MediaType, PollType
