@@ -1,24 +1,8 @@
 from typing import Optional
-from enum import auto
 
 from pydantic import BaseModel
-
-from .utils import AutoName
-
-
-class MediaType(AutoName):
-    animation = auto()
-    audio = auto()
-    document = auto()
-    photo = auto()
-    video = auto()
-    video_note = auto()
-    voice = auto()
-
-
-class PollType(AutoName):
-    quiz = auto()
-    regular = auto()
+from telectron.enums.message_media_type import MessageMediaType as MediaType
+from telectron.enums.poll_type import PollType
 
 
 class AnimationAttributes(BaseModel):
