@@ -12,6 +12,15 @@ class InlineKeyboardButton(Base):
 class InlineKeyboardMarkup(Base):
     inline_keyboard: List[List[InlineKeyboardButton]]
 
+    @classmethod
+    def from_telegram_type_dict(cls, obj) -> dict:
+        cls_dict = super().from_telegram_type_dict(obj)
+        if obj.inline_keyboard:
+            cls_dict['inline_keyboard'] = [[
+                InlineKeyboardButton.from_telegram_type(b) for b in row
+            ] for row in obj.inline_keyboard]
+        return cls_dict
+
 
 class KeyboardButton(Base):
     text: str
