@@ -1,18 +1,9 @@
 from typing import Optional, List
-from enum import auto
 
-from telegram_types.utils import AutoName
 from telegram_types.types import Restriction, ChatPhoto
 from telegram_types.base import Base
 
-
-class Status(str, AutoName):
-    online = auto()
-    offline = auto()
-    recently = auto()
-    within_week = auto()
-    within_month = auto()
-    long_time_ago = auto()
+from telectron.enums import UserStatus as Status
 
 
 class User(Base):
